"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
exports.getStyle = getStyle;
exports.setStyle = setStyle;
var _Position = _interopRequireDefault(require("../_statics/Position"));
/**
 * @file CursorPopCalculation vendor
 */

// Statics

/**
 * @param cursorOffset
 * @returns {*}
 */
function topVerticalBottom(cursorOffset) {
  return cursorOffset.top;
}

/**
 * @param cursorOffset
 * @param popupEl
 * @returns {number}
 */
function topVerticalTop(cursorOffset, popupEl) {
  return cursorOffset.top - popupEl.offsetHeight;
}

/**
 * @param cursorOffset
 * @returns {*}
 */
function topHorizontalTop(cursorOffset) {
  return cursorOffset.top;
}

/**
 * @param cursorOffset
 * @param popupEl
 * @returns {number}
 */
function topHorizontalMiddle(cursorOffset, popupEl) {
  return cursorOffset.top - popupEl.offsetHeight / 2;
}

/**
 * @param cursorOffset
 * @param popupEl
 * @returns {number}
 */
function topHorizontalBottom(cursorOffset, popupEl) {
  return cursorOffset.top - popupEl.offsetHeight;
}

/**
 * @param cursorOffset
 * @returns {*}
 */
function leftVerticalLeft(cursorOffset) {
  return cursorOffset.left;
}

/**
 * @param cursorOffset
 * @param popupEl
 * @returns {number}
 */
function leftVerticalCenter(cursorOffset, popupEl) {
  return cursorOffset.left - popupEl.offsetWidth / 2;
}

/**
 * @param cursorOffset
 * @param popupEl
 * @returns {number}
 */
function leftVerticalRight(cursorOffset, popupEl) {
  return cursorOffset.left - popupEl.offsetWidth;
}

/**
 * @param cursorOffset
 * @param popupEl
 * @returns {number}
 */
function leftHorizontalLeft(cursorOffset, popupEl) {
  return cursorOffset.left - popupEl.offsetWidth;
}

/**
 * @param cursorOffset
 * @returns {*}
 */
function leftHorizontalRight(cursorOffset) {
  return cursorOffset.left;
}

/**
 * @param parentEl
 * @param triggerEl
 * @param popupEl
 * @param scrollEl
 * @param position
 * @param cursorOffset
 * @returns {{}}
 */
function getStyle(parentEl, triggerEl, popupEl, scrollEl, position, cursorOffset) {
  if (!triggerEl || !popupEl) {
    return null;
  }
  var result = {
    position: 'fixed'
  };
  switch (position) {
    case _Position["default"].TOP_LEFT:
      {
        result.left = leftVerticalLeft(cursorOffset);
        result.top = topVerticalTop(cursorOffset, popupEl);
        break;
      }
    case _Position["default"].TOP:
      {
        result.left = leftVerticalCenter(cursorOffset, popupEl);
        result.top = topVerticalTop(cursorOffset, popupEl);
        break;
      }
    case _Position["default"].TOP_RIGHT:
      {
        result.left = leftVerticalRight(cursorOffset, popupEl);
        result.top = topVerticalTop(cursorOffset, popupEl);
        break;
      }
    case _Position["default"].BOTTOM_LEFT:
      {
        result.left = leftVerticalLeft(cursorOffset);
        result.top = topVerticalBottom(cursorOffset);
        break;
      }
    case _Position["default"].BOTTOM:
      {
        result.left = leftVerticalCenter(cursorOffset, popupEl);
        result.top = topVerticalBottom(cursorOffset);
        break;
      }
    case _Position["default"].BOTTOM_RIGHT:
      {
        result.left = leftVerticalRight(cursorOffset, popupEl);
        result.top = topVerticalBottom(cursorOffset);
        break;
      }
    case _Position["default"].LEFT_TOP:
      {
        result.left = leftHorizontalLeft(cursorOffset, popupEl);
        result.top = topHorizontalTop(cursorOffset);
        break;
      }
    case _Position["default"].LEFT:
      {
        result.left = leftHorizontalLeft(cursorOffset, popupEl);
        result.top = topHorizontalMiddle(cursorOffset, popupEl);
        break;
      }
    case _Position["default"].LEFT_BOTTOM:
      {
        result.left = leftHorizontalLeft(cursorOffset, popupEl);
        result.top = topHorizontalBottom(cursorOffset, popupEl);
        break;
      }
    case _Position["default"].RIGHT_TOP:
      {
        result.left = leftHorizontalRight(cursorOffset);
        result.top = topHorizontalTop(cursorOffset);
        break;
      }
    case _Position["default"].RIGHT:
      {
        result.left = leftHorizontalRight(cursorOffset);
        result.top = topHorizontalMiddle(cursorOffset, popupEl);
        break;
      }
    case _Position["default"].RIGHT_BOTTOM:
      {
        result.left = leftHorizontalRight(cursorOffset);
        result.top = topHorizontalBottom(cursorOffset, popupEl);
        break;
      }
    case _Position["default"].CENTER:
      {
        result.left = leftVerticalCenter(cursorOffset, popupEl);
        result.top = topHorizontalMiddle(cursorOffset, popupEl);
        break;
      }
  }
  return result;
}

/**
 * @param parentEl
 * @param triggerEl
 * @param popupEl
 * @param scrollEl
 * @param position
 * @param cursorOffset
 */
function setStyle(parentEl, triggerEl, popupEl, scrollEl, position, cursorOffset) {
  var style = getStyle(parentEl, triggerEl, popupEl, scrollEl, position, cursorOffset);
  if (!style) {
    return;
  }
  popupEl.style.left = style.left + 'px';
  popupEl.style.top = style.top + 'px';
  if (style.position) {
    popupEl.style.position = style.position;
  }
}
var _default = {
  getStyle: getStyle,
  setStyle: setStyle
};
exports["default"] = _default;