"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _reactDom = require("react-dom");
/**
 * @file DragDrop vendor
 */

function getSource() {
  return {
    beginDrag: function beginDrag(props) {
      return {
        index: props.index,
        groupIndex: props.groupIndex
      };
    }
  };
}
function getVerticalTarget() {
  return {
    hover: function hover(props, monitor, component) {
      // if in different group
      if (monitor.getItem().groupIndex !== props.groupIndex) {
        return;
      }
      var dragIndex = monitor.getItem().index;
      var hoverIndex = props.index;

      // Don't replace items with themselves
      if (dragIndex === hoverIndex) {
        return;
      }

      // Determine rectangle on screen
      var hoverBoundingRect = (0, _reactDom.findDOMNode)(component).getBoundingClientRect();

      // Get vertical middle
      var hoverMiddleY = (hoverBoundingRect.bottom - hoverBoundingRect.top) / 2;

      // Determine mouse position
      var clientOffset = monitor.getClientOffset();

      // Get pixels to the top
      var hoverClientY = clientOffset.y - hoverBoundingRect.top;

      // Only perform the move when the mouse has crossed half of the items height
      // When dragging downwards, only move when the cursor is below 50%
      // When dragging upwards, only move when the cursor is above 50%

      // Dragging downwards
      if (dragIndex < hoverIndex && hoverClientY < hoverMiddleY) {
        return;
      }

      // Dragging upwards
      if (dragIndex > hoverIndex && hoverClientY > hoverMiddleY) {
        return;
      }

      // Time to actually perform the action
      props.onMove(dragIndex, hoverIndex, props);

      // Note: we're mutating the monitor item here!
      // Generally it's better to avoid mutations,
      // but it's good here for the sake of performance
      // to avoid expensive index searches.
      monitor.getItem().index = hoverIndex;
    }
  };
}
function getHorizontalTarget() {
  return {
    hover: function hover(props, monitor, component) {
      // if in different group
      if (monitor.getItem().groupIndex !== props.groupIndex) {
        return;
      }
      var dragIndex = monitor.getItem().index;
      var hoverIndex = props.index;

      // Don't replace items with themselves
      if (dragIndex === hoverIndex) {
        return;
      }

      // Determine rectangle on screen
      var hoverBoundingRect = (0, _reactDom.findDOMNode)(component).getBoundingClientRect();

      // Get vertical middle
      var hoverMiddleX = (hoverBoundingRect.right - hoverBoundingRect.left) / 2;

      // Determine mouse position
      var clientOffset = monitor.getClientOffset();

      // Get pixels to the top
      var hoverClientX = clientOffset.x - hoverBoundingRect.left;

      // Only perform the move when the mouse has crossed half of the items height
      // When dragging downwards, only move when the cursor is below 50%
      // When dragging upwards, only move when the cursor is above 50%

      // Dragging downwards
      if (dragIndex < hoverIndex && hoverClientX < hoverMiddleX) {
        return;
      }

      // Dragging upwards
      if (dragIndex > hoverIndex && hoverClientX > hoverMiddleX) {
        return;
      }

      // Time to actually perform the action
      props.onMove(dragIndex, hoverIndex, props);

      // Note: we're mutating the monitor item here!
      // Generally it's better to avoid mutations,
      // but it's good here for the sake of performance
      // to avoid expensive index searches.
      monitor.getItem().index = hoverIndex;
    }
  };
}
var _default = {
  getSource: getSource,
  getVerticalTarget: getVerticalTarget,
  getHorizontalTarget: getHorizontalTarget
};
exports["default"] = _default;