"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _Position = _interopRequireDefault(require("../_statics/Position"));
/**
 * @file PositionPopCalculation vendor
 */

// Statics

/**
 * @param popupEl
 * @returns {number}
 */
function horizontalCenter(popupEl) {
  return (window.innerWidth - popupEl.offsetWidth) / 2;
}

/**
 * @param popupEl
 * @returns {number}
 */
function verticalMiddle(popupEl) {
  return (window.innerHeight - popupEl.offsetHeight) / 2;
}

/**
 * @param parentEl
 * @param popupEl
 * @param position
 * @returns {{}}
 */
function getStyle(parentEl, popupEl, position) {
  if (!popupEl) {
    return null;
  }
  var result = {};
  switch (position) {
    case _Position["default"].TOP_LEFT:
      {
        result.left = 0;
        result.top = 0;
        break;
      }
    case _Position["default"].TOP:
      {
        result.left = horizontalCenter(popupEl);
        result.top = 0;
        break;
      }
    case _Position["default"].TOP_RIGHT:
      {
        result.right = 0;
        result.top = 0;
        break;
      }
    case _Position["default"].BOTTOM_LEFT:
      {
        result.left = 0;
        result.bottom = 0;
        break;
      }
    case _Position["default"].BOTTOM:
      {
        result.left = horizontalCenter(popupEl);
        result.bottom = 0;
        break;
      }
    case _Position["default"].BOTTOM_RIGHT:
      {
        result.right = 0;
        result.bottom = 0;
        break;
      }
    case _Position["default"].LEFT_TOP:
      {
        result.left = 0;
        result.top = 0;
        break;
      }
    case _Position["default"].LEFT:
      {
        result.left = 0;
        result.top = verticalMiddle(popupEl);
        break;
      }
    case _Position["default"].LEFT_BOTTOM:
      {
        result.left = 0;
        result.bottom = 0;
        break;
      }
    case _Position["default"].RIGHT_TOP:
      {
        result.right = 0;
        result.top = 0;
        break;
      }
    case _Position["default"].RIGHT:
      {
        result.right = 0;
        result.top = verticalMiddle(popupEl);
        break;
      }
    case _Position["default"].RIGHT_BOTTOM:
      {
        result.right = 0;
        result.bottom = 0;
        break;
      }
    case _Position["default"].CENTER:
      {
        result.left = horizontalCenter(popupEl);
        result.top = verticalMiddle(popupEl);
        break;
      }
  }
  return result;
}

/**
 * @param parentEl
 * @param popupEl
 * @param position
 */
function setStyle(parentEl, popupEl, position) {
  if (!popupEl) {
    return;
  }
  var style = getStyle(parentEl, popupEl, position);
  if (!style) {
    return;
  }
  popupEl.style.left = popupEl.style.right = popupEl.style.top = popupEl.style.bottom = 'auto';
  Object.entries(style).forEach(function (_ref) {
    var _ref2 = (0, _slicedToArray2["default"])(_ref, 2),
      key = _ref2[0],
      value = _ref2[1];
    return popupEl.style[key] = value + 'px';
  });
}
var _default = {
  getStyle: getStyle,
  setStyle: setStyle
};
exports["default"] = _default;