"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.calcSpan = calcSpan;
exports["default"] = void 0;
exports.formatColumnsSpan = formatColumnsSpan;
exports.formatValue = formatValue;
exports.getAdvancedColumnsSpan = getAdvancedColumnsSpan;
exports.getBodyColumns = getBodyColumns;
exports.getColumnKey = getColumnKey;
exports.getColumnsSpan = getColumnsSpan;
exports.getColumnsTotalWidth = getColumnsTotalWidth;
exports.getFirstColumn = getFirstColumn;
exports.getHeadColumns = getHeadColumns;
exports.getPageSizeValue = getPageSizeValue;
exports.getStickyColumnStyle = getStickyColumnStyle;
exports.handleDeselect = handleDeselect;
exports.handleNoWrap = handleNoWrap;
exports.handlePage = handlePage;
exports.handleSelect = handleSelect;
exports.handleSelectAll = handleSelectAll;
exports.hasHeadRenderer = hasHeadRenderer;
exports.hasRenderer = hasRenderer;
exports.indexOfNodeInValue = indexOfNodeInValue;
exports.isNodeChecked = isNodeChecked;
exports.isNodeDisabled = isNodeDisabled;
exports.isSelectAllChecked = isSelectAllChecked;
exports.needCollapseButtonSpacing = needCollapseButtonSpacing;
exports.recursiveSelectChildren = recursiveSelectChildren;
exports.sortColumns = sortColumns;
exports.sortTableData = sortTableData;
var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _HorizontalAlign = _interopRequireDefault(require("../_statics/HorizontalAlign"));
var _VirtualRoot = _interopRequireDefault(require("../_statics/VirtualRoot"));
var _TableFragment = _interopRequireDefault(require("../_statics/TableFragment"));
var _Direction = _interopRequireDefault(require("../_statics/Direction"));
var _isArray = _interopRequireDefault(require("lodash/isArray"));
var _Util = _interopRequireDefault(require("../_vendors/Util"));
var _Valid = _interopRequireDefault(require("../_vendors/Valid"));
var _ScrollBar = _interopRequireDefault(require("../_vendors/ScrollBar"));
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
/**
 * Calculate column span by fragment
 * @param fragment
 * @param column
 * @param data
 * @param colIndex
 * @param rowIndex
 * @param columns
 * @returns {*}
 */
function calcSpan(fragment, column, data, colIndex, rowIndex, columns) {
  var span = column["".concat(fragment, "Span")];
  return span && typeof span === 'function' ? span(data, colIndex, rowIndex, columns) : +span;
}

/**
 * @param column
 * @param columnKeyField
 * @returns {*}
 */
function getColumnKey(column, columnKeyField) {
  return column && columnKeyField && column[columnKeyField] || column;
}

/**
 * Get columns span
 * @param fragment
 * @param columns
 * @param data
 * @param rowIndex
 * @returns {[]|*}
 */
function getColumnsSpan(fragment, columns, data, rowIndex) {
  if (!fragment) {
    return columns.map(function (column) {
      return _objectSpread(_objectSpread({}, column), {}, {
        span: 1
      });
    });
  }
  var result = [];
  var spanFlag = 1;
  for (var colIndex = 0, len = columns.length; colIndex < len; colIndex++) {
    if (spanFlag > 1) {
      spanFlag--;
      continue;
    }
    var column = columns[colIndex];
    var span = calcSpan(fragment, columns[colIndex], data, colIndex, rowIndex, columns);
    if (span && span > 1) {
      spanFlag = span;
    }
    result.push({
      column: column,
      span: span,
      originColumnIndex: colIndex
    });
  }
  return result;
}

/**
 * Get the correct column span when some columns are frozen
 * @param originColumns
 * @param fragment
 * @param columns
 * @param data
 * @param rowIndex
 * @returns {[]|*}
 */
function getAdvancedColumnsSpan(originColumns, fragment, columns, data, rowIndex) {
  if (!fragment) {
    return columns.map(function (column) {
      return _objectSpread(_objectSpread({}, column), {}, {
        span: 1
      });
    });
  }
  var result = [];
  var span = 1;
  var _loop = function _loop(colIndex, len) {
    if (span > 1) {
      span--;
      return "continue";
    }
    var column = columns[colIndex];
    if (column) {
      span = calcSpan(fragment, columns[colIndex], data, colIndex, rowIndex, originColumns) || 1;
      if (span > 1) {
        var index = originColumns.indexOf(column);
        var spanColumns = originColumns.slice(index + 1, index + span);
        if (column.fixed === _HorizontalAlign["default"].LEFT || column.fixed === _HorizontalAlign["default"].RIGHT) {
          span = spanColumns.filter(function (item) {
            return item && item.fixed === column.fixed;
          }).length + 1;
        } else {
          span -= spanColumns.filter(function (item) {
            return item && (item.fixed || _HorizontalAlign["default"].CENTER) !== (column.fixed || _HorizontalAlign["default"].CENTER);
          }).length;
        }
      }
    }
    result.push({
      column: column,
      span: span > 1 ? span : null,
      originColumnIndex: colIndex
    });
  };
  for (var colIndex = 0, len = columns.length; colIndex < len; colIndex++) {
    var _ret = _loop(colIndex, len);
    if (_ret === "continue") continue;
  }
  return result;
}

/**
 * @param data
 * @param sorting
 * @param sortFunc
 * @returns {*[]|*}
 */
function sortTableData(data, sorting, sortFunc) {
  if (!data) {
    return [];
  }
  if (!sorting) {
    return data;
  }
  var copyData = data.slice();
  if (sortFunc) {
    copyData = sortFunc(copyData, sorting);
  } else {
    copyData.sort(function (a, b) {
      if (!isNaN(a[sorting.prop]) && !isNaN(b[sorting.prop])) {
        return (Number(a[sorting.prop]) - Number(b[sorting.prop])) * sorting.type;
      } else {
        return (a[sorting.prop] + '').localeCompare(b[sorting.prop] + '') * sorting.type;
      }
    });
  }
  return copyData;
}

/**
 * @param columns
 * @param fragment
 * @returns {*|boolean}
 */
function hasRenderer(columns, fragment) {
  return columns && columns.length > 0 && fragment ? columns.some(function (column) {
    return column === null || column === void 0 ? void 0 : column["".concat(fragment, "Renderer")];
  }) : false;
}

/**
 * @param columnsGroup
 * @returns {*|boolean}
 */
function hasHeadRenderer(columnsGroup) {
  return columnsGroup && columnsGroup.length > 0 ? columnsGroup.some(function (columns) {
    return hasRenderer(columns, _TableFragment["default"].HEAD);
  }) : false;
}

// export function hasFixedColumn(columns, fixed) {
//     return columns && fixed ? columns.some(column => column && column.fixed === fixed) : false;
// }

// export function getDataByPagination(data, isPaginated, pagination) {
//
//     if (!data || data.length < 1) {
//         return [];
//     }
//
//     if (!isPaginated || !pagination) {
//         return data;
//     }
//
//     return data.slice(pagination.page * pagination.pageSize, (pagination.page + 1) * pagination.pageSize)
//                .filter(item => item && !item.disabled);
//
// }

/**
 * @param node
 * @param value
 * @param idField
 * @returns {number|*}
 */
function indexOfNodeInValue(node, value, idField) {
  if (!node || !value) {
    return -1;
  }
  var index = value.findIndex(function (item) {
    return item && item.hasOwnProperty(idField) && node.hasOwnProperty(idField) && item[idField] === node[idField];
  });
  if (index < 0) {
    index = value.indexOf(node);
  }
  return index;
}

/**
 * @param node
 * @param value
 * @param idField
 * @returns {boolean}
 */
function isNodeChecked(node, value, idField) {
  return indexOfNodeInValue(node, value, idField) >= 0;
}

/**
 * @param node
 * @param isRowDisabled
 * @returns {boolean}
 */
function isNodeDisabled(node, isRowDisabled) {
  if (!node) {
    return false;
  }
  if (node.disabled) {
    return true;
  }
  if (typeof isRowDisabled === 'function') {
    return isRowDisabled(node) || false;
  }
  return isRowDisabled || false;
}

/**
 * @param data
 * @param value
 * @param idField
 * @returns {{indeterminate: boolean, checked: boolean}}
 */
function isSelectAllChecked(data, value, idField) {
  var _ref;
  var root = (0, _isArray["default"])(data) ? (_ref = {}, (0, _defineProperty2["default"])(_ref, _VirtualRoot["default"], true), (0, _defineProperty2["default"])(_ref, "children", data), _ref) : _objectSpread(_objectSpread({}, data), {}, (0, _defineProperty2["default"])({}, _VirtualRoot["default"], true));
  var total = 0,
    count = 0;
  _Util["default"].preOrderTraverse(root, function (node) {
    if (node && !node.disabled && !(_VirtualRoot["default"] in node)) {
      total++;
      if (isNodeChecked(node, value, idField)) {
        count++;
      }
    }
  });
  return {
    checked: total > 0 && count === total,
    indeterminate: count > 0 && total !== count
  };
}

/**
 * @param node
 * @param value
 * @param idField
 * @param isSelectRecursive
 * @returns {*[]}
 */
function handleSelect(node) {
  var value = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var idField = arguments.length > 2 ? arguments[2] : undefined;
  var isSelectRecursive = arguments.length > 3 ? arguments[3] : undefined;
  if (!node || node.disabled || !value) {
    return value;
  }
  if (!isNodeChecked(node, value, idField)) {
    value.push(node);
  }
  if (!isSelectRecursive || !node.children || node.children.length < 1) {
    return value;
  }
  var _iterator = _createForOfIteratorHelper(node.children),
    _step;
  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var item = _step.value;
      handleSelect(item, value, idField, isSelectRecursive);
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }
  return value;
}

/**
 * @param node
 * @param value
 * @param idField
 * @param isSelectRecursive
 * @returns {*}
 */
function handleDeselect(node, value, idField, isSelectRecursive) {
  if (!node || node.disabled || !value) {
    return value;
  }
  var index = indexOfNodeInValue(node, value, idField);
  if (index > -1) {
    value.splice(index, 1);
  }
  if (!isSelectRecursive || !node.children || node.children.length < 1) {
    return value;
  }
  var _iterator2 = _createForOfIteratorHelper(node.children),
    _step2;
  try {
    for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
      var item = _step2.value;
      handleDeselect(item, value, idField);
    }
  } catch (err) {
    _iterator2.e(err);
  } finally {
    _iterator2.f();
  }
  return value;
}

/**
 * @param value
 * @param data
 * @param idField
 * @returns {*[]}
 */
function formatValue(value, data, idField) {
  var _Util$postOrderTraver;
  var result = [];
  _Util["default"].postOrderTraverse((_Util$postOrderTraver = {}, (0, _defineProperty2["default"])(_Util$postOrderTraver, _VirtualRoot["default"], true), (0, _defineProperty2["default"])(_Util$postOrderTraver, "children", data), _Util$postOrderTraver), function (node) {
    if (!(_VirtualRoot["default"] in node)) {
      if (!node.children || node.children.length < 1) {
        if (isNodeChecked(node, value, idField)) {
          result.push(node);
        }
      } else {
        if (node.children.every(function (child) {
          return isNodeChecked(child, value, idField);
        })) {
          result.push(node);
        }
      }
    }
  });
  return result;
}

/**
 * @param data
 * @param value
 * @param idField
 * @returns {*[]}
 */
function handleSelectAll(data) {
  var value = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var idField = arguments.length > 2 ? arguments[2] : undefined;
  if (!data || data.length < 1) {
    return value;
  }
  data.forEach(function (node) {
    return handleSelect(node, value, idField, true);
  });
  return value;
}

/**
 * Separate columns to left, center and right, and check has fixed columns or not
 * @param columns
 * @returns {{hasFixedLeftColumn: (Array|boolean), sortedColumns: *[], hasFixedRightColumn: (Array|boolean)}|*}
 */
function sortColumns(columns) {
  var _result;
  if (!columns || columns.length < 1) {
    return columns;
  }
  var result = (_result = {}, (0, _defineProperty2["default"])(_result, _HorizontalAlign["default"].LEFT, []), (0, _defineProperty2["default"])(_result, _HorizontalAlign["default"].CENTER, []), (0, _defineProperty2["default"])(_result, _HorizontalAlign["default"].RIGHT, []), _result);

  // Separate root column to left, center and right
  columns.forEach(function (column) {
    return column && result[column.fixed || _HorizontalAlign["default"].CENTER].push(column);
  });

  // Traverse all children nodes in left and right, update "fixed" property inheriting from their parent
  _Util["default"].preOrderTraverse({
    children: result[_HorizontalAlign["default"].LEFT]
  }, function (node, depth, index, parent) {
    var _parent$children;
    if (parent !== null && parent !== void 0 && (_parent$children = parent.children) !== null && _parent$children !== void 0 && _parent$children[index]) {
      parent.children = (0, _toConsumableArray2["default"])(parent.children);
      parent.children[index] = _objectSpread(_objectSpread({}, parent.children[index]), {}, {
        fixed: _HorizontalAlign["default"].LEFT
      });
    }
  });
  _Util["default"].preOrderTraverse({
    children: result[_HorizontalAlign["default"].RIGHT]
  }, function (node, depth, index, parent) {
    var _parent$children2;
    if (parent !== null && parent !== void 0 && (_parent$children2 = parent.children) !== null && _parent$children2 !== void 0 && _parent$children2[index]) {
      parent.children = (0, _toConsumableArray2["default"])(parent.children);
      parent.children[index] = _objectSpread(_objectSpread({}, parent.children[index]), {}, {
        fixed: _HorizontalAlign["default"].RIGHT
      });
    }
  });
  return {
    sortedColumns: [].concat((0, _toConsumableArray2["default"])(result[_HorizontalAlign["default"].LEFT]), (0, _toConsumableArray2["default"])(result[_HorizontalAlign["default"].CENTER]), (0, _toConsumableArray2["default"])(result[_HorizontalAlign["default"].RIGHT])),
    hasFixedLeftColumn: result[_HorizontalAlign["default"].LEFT] && result[_HorizontalAlign["default"].LEFT].length > 0,
    hasFixedRightColumn: result[_HorizontalAlign["default"].RIGHT] && result[_HorizontalAlign["default"].RIGHT].length > 0
  };
}

/**
 * Get the deepest first child of columns
 * @param columns
 * @returns {null|*}
 */
function getFirstColumn(columns) {
  if (!columns || columns.length < 1) {
    return null;
  }
  if (columns[0] && (!columns[0].children || columns[0].children.length < 1)) {
    return columns[0];
  }
  return getFirstColumn(columns[0].children);
}

/**
 * Calculate the row span and column span
 * @param node
 * @param maxDepth
 * @param depth
 * @returns {number|*}
 */
function formatColumnsSpan(node, maxDepth) {
  var depth = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : -1;
  if (!node) {
    return 0;
  }
  var hasChildren = node.children && node.children.length > 0;
  var colSpan = 0;
  if (hasChildren) {
    node.children.forEach(function (childNode) {
      return childNode && (colSpan += formatColumnsSpan(childNode, maxDepth, depth + 1));
    });

    // column span
    if (colSpan > 1) {
      node.colSpan = colSpan;
    }
  } else {
    // row span
    var rowSpan = maxDepth - depth;
    if (rowSpan > 1) {
      node.rowSpan = rowSpan;
    }
  }
  if (node[_VirtualRoot["default"]]) {
    return node.children;
  }
  if (hasChildren) {
    return colSpan;
  }
  return 1;
}

/**
 * Get head columns
 * transform the columns data (tree construction) to html tr-th row format
 * @param columns
 * @returns {Array|*}
 */
function getHeadColumns(columns) {
  var _formatColumnsSpan, _Util$preOrderTravers;
  if (!columns || columns.length < 1) {
    return columns;
  }

  // Calculate the max depth
  var maxDepth = 0;
  _Util["default"].postOrderTraverse({
    children: columns
  }, function (node, depth) {
    if (depth > maxDepth) {
      maxDepth = depth;
    }
  });

  // Add row span and column span to column node
  var formatedColumns = formatColumnsSpan((_formatColumnsSpan = {}, (0, _defineProperty2["default"])(_formatColumnsSpan, _VirtualRoot["default"], true), (0, _defineProperty2["default"])(_formatColumnsSpan, "children", columns), _formatColumnsSpan), maxDepth);
  var result = [];
  _Util["default"].preOrderTraverse((_Util$preOrderTravers = {}, (0, _defineProperty2["default"])(_Util$preOrderTravers, _VirtualRoot["default"], true), (0, _defineProperty2["default"])(_Util$preOrderTravers, "children", formatedColumns), _Util$preOrderTravers), function (column, depth, index, parentColumn) {
    var rowIndex = depth - 1;
    var rowSpan = (column === null || column === void 0 ? void 0 : column.rowSpan) || 1;
    for (var i = rowIndex, len = rowIndex + rowSpan; i < len; i++) {
      if (i >= 0) {
        if (!result[i]) {
          result[i] = [];
        }
        if (i > rowIndex) {
          result[i].push(_objectSpread(_objectSpread({}, column), {}, {
            hidden: true
          }));
        } else {
          result[i].push(column);
        }
      }
    }
  });
  return result;
}

/**
 * @param columns
 * @returns {*[]|*}
 */
function getBodyColumns(columns) {
  if (!columns || columns.length < 1) {
    return columns;
  }
  var result = [];
  _Util["default"].postOrderTraverse({
    children: columns
  }, function (column) {
    if (column && (!column.children || column.children.length < 1)) {
      result.push(column);
    }
  });
  return result;
}

/**
 * @param node
 * @param value
 * @param idField
 * @returns {*[]}
 */
function recursiveSelectChildren(node) {
  var value = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var idField = arguments.length > 2 ? arguments[2] : undefined;
  if (!node) {
    return value;
  }
  _Util["default"].preOrderTraverse(node, function (child) {
    if (!isNodeChecked(child, value, idField)) {
      value.push(child);
    }
  });
  return value;
}

/**
 * @param tableData
 * @returns {*}
 */
function needCollapseButtonSpacing(tableData) {
  return tableData && tableData.some(function (rowData) {
    return rowData && rowData.children && rowData.children.length > 0;
  });
}

/**
 * @param pageSize
 * @param pageSizeValueField
 * @returns {*}
 */
function getPageSizeValue(pageSize, pageSizeValueField) {
  return (0, _typeof2["default"])(pageSize) === 'object' ? pageSize[pageSizeValueField] : pageSize;
}

/**
 * @param fragmentNoWrap
 * @param columnNoWrap
 * @param data
 * @param colIndex
 * @param rowIndex
 * @param tableData
 * @returns {boolean}
 */
function handleNoWrap(fragmentNoWrap, columnNoWrap, _ref2) {
  var data = _ref2.data,
    colIndex = _ref2.colIndex,
    rowIndex = _ref2.rowIndex,
    tableData = _ref2.tableData;
  return !!((typeof fragmentNoWrap === 'function' ? fragmentNoWrap(data, colIndex, rowIndex, tableData) : fragmentNoWrap) || (typeof columnNoWrap === 'function' ? columnNoWrap(data, colIndex, rowIndex, tableData) : columnNoWrap));
}

/**
 * @param page
 * @param pageSize
 * @param data
 * @returns {number|*}
 */
function handlePage(page, pageSize, data) {
  if (!data || data.length < 1 || !pageSize || page < 0) {
    return 0;
  }
  return _Valid["default"].range(page, 0, Math.ceil(data.length / pageSize) - 1);
}

// export function getColumnByPath(columns, path) {
//
//     if (!columns || columns.length < 1 || !path || path.length < 1) {
//         return null;
//     }
//
//     let result = {children: columns};
//     path.forEach(pathIndex => result = result.children[pathIndex]);
//
//     return result;
//
// }

/**
 * @param columns
 * @param columnKeyField
 * @param columnsWidth
 * @param defaultColumnWidth
 * @returns {*|number}
 */
function getColumnsTotalWidth(columns) {
  var columnKeyField = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'key';
  var columnsWidth = arguments.length > 2 ? arguments[2] : undefined;
  var defaultColumnWidth = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 100;
  return columns && columnsWidth ? columns.reduce(function (sum, column) {
    var _column$children;
    return sum + ((column === null || column === void 0 ? void 0 : (_column$children = column.children) === null || _column$children === void 0 ? void 0 : _column$children.length) > 0 ? getColumnsTotalWidth(column === null || column === void 0 ? void 0 : column.children, columnKeyField, columnsWidth, defaultColumnWidth) : columnsWidth.get(getColumnKey(column, columnKeyField)) || defaultColumnWidth);
  }, 0) : 0;
}

/**
 * @param fixed
 * @param colIndex
 * @param columns
 * @param columnKeyField
 * @param columnsWidth
 * @param defaultColumnWidth
 * @param hasVerticalScroll
 * @returns {{}}
 */
function getStickyColumnStyle(fixed, colIndex, columns) {
  var columnKeyField = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'key';
  var columnsWidth = arguments.length > 4 ? arguments[4] : undefined;
  var defaultColumnWidth = arguments.length > 5 ? arguments[5] : undefined;
  var hasVerticalScroll = arguments.length > 6 ? arguments[6] : undefined;
  if (fixed === _HorizontalAlign["default"].LEFT) {
    return {
      position: 'sticky',
      left: getColumnsTotalWidth(columns.slice(0, colIndex), columnKeyField, columnsWidth, defaultColumnWidth)
    };
  }
  if (fixed === _HorizontalAlign["default"].RIGHT) {
    return {
      position: 'sticky',
      right: getColumnsTotalWidth(columns.slice(colIndex + 1), columnKeyField, columnsWidth, defaultColumnWidth) + (hasVerticalScroll ? _ScrollBar["default"].getSize(_Direction["default"].VERTICAL) : 0)
    };
  }
  return {};
}
var _default = {
  calcSpan: calcSpan,
  getColumnKey: getColumnKey,
  getColumnsSpan: getColumnsSpan,
  // fixColumnSpan,
  getAdvancedColumnsSpan: getAdvancedColumnsSpan,
  sortTableData: sortTableData,
  hasRenderer: hasRenderer,
  hasHeadRenderer: hasHeadRenderer,
  // hasFixedColumn,
  // getDataByPagination,
  indexOfNodeInValue: indexOfNodeInValue,
  isNodeChecked: isNodeChecked,
  isNodeDisabled: isNodeDisabled,
  isSelectAllChecked: isSelectAllChecked,
  handleSelect: handleSelect,
  handleDeselect: handleDeselect,
  formatValue: formatValue,
  handleSelectAll: handleSelectAll,
  sortColumns: sortColumns,
  getFirstColumn: getFirstColumn,
  getHeadColumns: getHeadColumns,
  getBodyColumns: getBodyColumns,
  recursiveSelectChildren: recursiveSelectChildren,
  needCollapseButtonSpacing: needCollapseButtonSpacing,
  getPageSizeValue: getPageSizeValue,
  handleNoWrap: handleNoWrap,
  handlePage: handlePage,
  // getColumnByPath,
  getColumnsTotalWidth: getColumnsTotalWidth,
  getStickyColumnStyle: getStickyColumnStyle
};
exports["default"] = _default;