"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
exports.getStyle = getStyle;
exports.setStyle = setStyle;
var _contains = _interopRequireDefault(require("dom-helpers/contains"));
var _Dom = _interopRequireDefault(require("./Dom"));
var _Position = _interopRequireDefault(require("../_statics/Position"));
/**
 * @file TriggerPopCalculation vendor
 */

/**
 * @param triggerEl
 * @param triggerOffset
 * @returns {*}
 */
function topVerticalBottom(triggerEl, triggerOffset) {
  return triggerOffset.top + triggerEl.offsetHeight;
}

/**
 * @param triggerOffset
 * @param popupEl
 * @returns {number}
 */
function topVerticalTop(triggerOffset, popupEl) {
  return triggerOffset.top - popupEl.offsetHeight - parseInt(getComputedStyle(popupEl).marginTop, 10) - parseInt(getComputedStyle(popupEl).marginBottom, 10);
}

/**
 * @param triggerOffset
 * @returns {*}
 */
function topHorizontalTop(triggerOffset) {
  return triggerOffset.top;
}

/**
 * @param triggerEl
 * @param triggerOffset
 * @param popupEl
 * @returns {number}
 */
function topHorizontalMiddle(triggerEl, triggerOffset, popupEl) {
  return triggerOffset.top + triggerEl.offsetHeight / 2 - popupEl.offsetHeight / 2;
}

/**
 * @param triggerEl
 * @param triggerOffset
 * @param popupEl
 * @returns {number}
 */
function topHorizontalBottom(triggerEl, triggerOffset, popupEl) {
  return triggerOffset.top + triggerEl.offsetHeight - popupEl.offsetHeight;
}

/**
 * @param triggerOffset
 * @returns {*}
 */
function leftVerticalLeft(triggerOffset) {
  return triggerOffset.left;
}

/**
 * @param triggerEl
 * @param triggerOffset
 * @param popupEl
 * @returns {number}
 */
function leftVerticalCenter(triggerEl, triggerOffset, popupEl) {
  return triggerOffset.left + triggerEl.offsetWidth / 2 - popupEl.offsetWidth / 2;
}

/**
 * @param triggerEl
 * @param triggerOffset
 * @param popupEl
 * @returns {number}
 */
function leftVerticalRight(triggerEl, triggerOffset, popupEl) {
  return triggerOffset.left - (popupEl.offsetWidth - triggerEl.offsetWidth);
}

/**
 * @param triggerOffset
 * @param popupEl
 * @returns {number}
 */
function leftHorizontalLeft(triggerOffset, popupEl) {
  return triggerOffset.left - popupEl.offsetWidth - parseInt(getComputedStyle(popupEl).marginLeft, 10) - parseInt(getComputedStyle(popupEl).marginRight, 10);
}

/**
 * @param triggerEl
 * @param triggerOffset
 * @returns {*}
 */
function leftHorizontalRight(triggerEl, triggerOffset) {
  return triggerOffset.left + triggerEl.offsetWidth;
}

/**
 * @param parentEl
 * @param triggerEl
 * @param popupEl
 * @param scrollEl
 * @param position
 * @returns {{}}
 */
function getStyle(parentEl, triggerEl, popupEl, scrollEl, position) {
  if (!triggerEl || !popupEl) {
    return null;
  }
  var triggerOffset = _Dom["default"].getOffset(triggerEl, parentEl);
  var result = {};
  switch (position) {
    case _Position["default"].TOP_LEFT:
      {
        result.left = leftVerticalLeft(triggerOffset);
        result.top = topVerticalTop(triggerOffset, popupEl);
        break;
      }
    case _Position["default"].TOP:
      {
        result.left = leftVerticalCenter(triggerEl, triggerOffset, popupEl);
        result.top = topVerticalTop(triggerOffset, popupEl);
        break;
      }
    case _Position["default"].TOP_RIGHT:
      {
        result.left = leftVerticalRight(triggerEl, triggerOffset, popupEl);
        result.top = topVerticalTop(triggerOffset, popupEl);
        break;
      }
    case _Position["default"].BOTTOM_LEFT:
      {
        result.left = leftVerticalLeft(triggerOffset);
        result.top = topVerticalBottom(triggerEl, triggerOffset);
        break;
      }
    case _Position["default"].BOTTOM:
      {
        result.left = leftVerticalCenter(triggerEl, triggerOffset, popupEl);
        result.top = topVerticalBottom(triggerEl, triggerOffset);
        break;
      }
    case _Position["default"].BOTTOM_RIGHT:
      {
        result.left = leftVerticalRight(triggerEl, triggerOffset, popupEl);
        result.top = topVerticalBottom(triggerEl, triggerOffset);
        break;
      }
    case _Position["default"].LEFT_TOP:
      {
        result.left = leftHorizontalLeft(triggerOffset, popupEl);
        result.top = topHorizontalTop(triggerOffset);
        break;
      }
    case _Position["default"].LEFT:
      {
        result.left = leftHorizontalLeft(triggerOffset, popupEl);
        result.top = topHorizontalMiddle(triggerEl, triggerOffset, popupEl);
        break;
      }
    case _Position["default"].LEFT_BOTTOM:
      {
        result.left = leftHorizontalLeft(triggerOffset, popupEl);
        result.top = topHorizontalBottom(triggerEl, triggerOffset, popupEl);
        break;
      }
    case _Position["default"].RIGHT_TOP:
      {
        result.left = leftHorizontalRight(triggerEl, triggerOffset);
        result.top = topHorizontalTop(triggerOffset);
        break;
      }
    case _Position["default"].RIGHT:
      {
        result.left = leftHorizontalRight(triggerEl, triggerOffset);
        result.top = topHorizontalMiddle(triggerEl, triggerOffset, popupEl);
        break;
      }
    case _Position["default"].RIGHT_BOTTOM:
      {
        result.left = leftHorizontalRight(triggerEl, triggerOffset);
        result.top = topHorizontalBottom(triggerEl, triggerOffset, popupEl);
        break;
      }
    case _Position["default"].CENTER:
      {
        result.left = leftVerticalCenter(triggerEl, triggerOffset, popupEl);
        result.top = topHorizontalMiddle(triggerEl, triggerOffset, popupEl);
        break;
      }
  }

  // to solve the fixed parent element problem
  var closestFixedEl = _Dom["default"].getClosestFixed(triggerEl);
  if (closestFixedEl && parentEl && (0, _contains["default"])(parentEl, closestFixedEl)) {
    result.position = 'fixed';
  }
  return result;
}

/**
 * @param parentEl
 * @param triggerEl
 * @param popupEl
 * @param scrollEl
 * @param position
 */
function setStyle(parentEl, triggerEl, popupEl, scrollEl, position) {
  var style = getStyle(parentEl, triggerEl, popupEl, scrollEl, position);
  if (!style) {
    return;
  }
  popupEl.style.left = style.left + 'px';
  popupEl.style.top = style.top + 'px';
  if (style.position) {
    popupEl.style.position = style.position;
  }
}
var _default = {
  getStyle: getStyle,
  setStyle: setStyle
};
exports["default"] = _default;