"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
exports.enumerateValue = enumerateValue;
exports.formatCapitalize = formatCapitalize;
exports.genIndexArray = genIndexArray;
exports.getDiag = getDiag;
exports.getTextByDisplayField = getTextByDisplayField;
exports.getValueByValueField = getValueByValueField;
exports.isEnableCookieAndStorage = isEnableCookieAndStorage;
exports.isEnableLocalStorage = isEnableLocalStorage;
exports.isEnableSessionStorage = isEnableSessionStorage;
exports.isValueEqual = isValueEqual;
exports.postOrderTraverse = postOrderTraverse;
exports.preOrderTraverse = preOrderTraverse;
exports.reorder = reorder;
exports.shallowCloneMap = shallowCloneMap;
exports.tree = tree;
exports.value2Moment = value2Moment;
exports.value2Timestamp = value2Timestamp;
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));
var _moment = _interopRequireDefault(require("moment"));
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }
/**
 * @returns {boolean}
 */
function isEnableLocalStorage() {
  try {
    return 'localStorage' in window && window['localStorage'] !== null;
  } catch (e) {
    return false;
  }
}

/**
 * @returns {boolean}
 */
function isEnableSessionStorage() {
  try {
    return 'sessionStorage' in window && window['sessionStorage'] !== null;
  } catch (e) {
    return false;
  }
}

/**
 * @returns {boolean}
 */
function isEnableCookieAndStorage() {
  return navigator.cookieEnabled && isEnableLocalStorage() && isEnableSessionStorage();
}

/**
 * @param value
 * @returns {string|*}
 */
function formatCapitalize(value) {
  return value ? value.charAt(0).toUpperCase() + value.substring(1).toLowerCase() : value;
}

/**
 * @param value
 * @param format
 * @returns {number|number}
 */
function value2Timestamp(value, format) {
  var defaultValue = new Date().getTime();
  if (typeof value === 'number') {
    return new Date(value).toString() === 'Invalid Date' ? defaultValue : value;
  } else if (typeof value === 'string') {
    var date = (0, _moment["default"])(value, format);
    return date.isValid() ? date.valueOf() : defaultValue;
  } else if (_moment["default"].isDate(value)) {
    var _date = (0, _moment["default"])(value);
    return _date.isValid() ? _date.valueOf() : defaultValue;
  }
  return defaultValue;
}

/**
 * @param value
 * @param format
 * @returns {moment.Moment}
 */
function value2Moment(value, format) {
  var defaultValue = (0, _moment["default"])();
  if (typeof value === 'string') {
    var date = (0, _moment["default"])(value, format);
    return date.isValid() ? date : defaultValue;
  } else {
    var _date2 = (0, _moment["default"])(value);
    return _date2.isValid() ? _date2 : defaultValue;
  }
}

/**
 * enumerate object value for PropTypes.oneOf
 * @param enumerate
 * @returns {*[]}
 */
function enumerateValue(enumerate) {
  if (!enumerate) {
    return null;
  }
  return Object.keys(enumerate).map(function (key) {
    return enumerate[key];
  });
}

/**
 * @param data
 * @param callback
 */
function tree(data, callback) {
  var loop = function loop(children, level) {
    children.forEach(function (item, index) {
      var pos = level + '-' + (1 + index);
      if (item.children) {
        loop(item.children, pos);
      }
      callback(item, index, pos);
    });
  };
  loop(data, 1);
}

/**
 * @param data
 * @param valueField
 * @param displayField
 * @returns {*}
 */
function getValueByValueField(data) {
  var valueField = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'value';
  var displayField = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'text';
  if (data == null) {
    return;
  }
  if ((0, _typeof2["default"])(data) === 'object') {
    return data[valueField] == null ? data[displayField] : data[valueField];
  }
  return data;
}

/**
 * @param data
 * @param displayField
 * @param valueField
 * @returns {string|*}
 */
function getTextByDisplayField(data) {
  var displayField = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'text';
  var valueField = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'value';
  if (data == null) {
    return '';
  }
  if ((0, _typeof2["default"])(data) === 'object') {
    return data[displayField] == null ? data[valueField] : data[displayField];
  }
  return data;
}

/**
 * @param data1
 * @param data2
 * @param valueField
 * @param displayField
 * @returns {boolean}
 */
function isValueEqual(data1, data2) {
  var valueField = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'value';
  var displayField = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'text';
  return getValueByValueField(data1, valueField, displayField) === getValueByValueField(data2, valueField, displayField);
}

/**
 * @param len
 * @returns {*[]}
 */
function genIndexArray(len) {
  if (!len || isNaN(len) || len < 1) {
    return [];
  }
  var result = [];
  for (var i = 0; i < len; i++) {
    result[i] = i;
  }
  return result;
}

/**
 * @param a
 * @param b
 * @returns {number}
 */
function getDiag(a, b) {
  return Math.sqrt(a * a + b * b);
}

/**
 * @param data
 * @param startIndex
 * @param endIndex
 */
function reorder(data, startIndex, endIndex) {
  if (!data || !(startIndex in data) || !(startIndex in data)) {
    return;
  }
  var _data$splice = data.splice(startIndex, 1),
    _data$splice2 = (0, _slicedToArray2["default"])(_data$splice, 1),
    removed = _data$splice2[0];
  data.splice(endIndex, 0, removed);
}

/**
 * @param node
 * @param callback
 * @param depth
 * @param index
 * @param parent
 * @param path
 * @returns {boolean}
 */
function preOrderTraverse(node, callback) {
  var depth = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  var index = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
  var parent = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : null;
  var path = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : null;
  if (callback(node, depth, index, parent, path) === false) {
    return false;
  }
  if (node.children && node.children.length > 0) {
    for (var i = 0, len = node.children.length; i < len; i++) {
      if (preOrderTraverse(node.children[i], callback, depth + 1, i, node, path ? [].concat((0, _toConsumableArray2["default"])(path), [i]) : [i]) === false) {
        break;
      }
    }
  }
}

/**
 * @param node
 * @param callback
 * @param depth
 * @param index
 * @param parent
 * @param path
 * @returns {boolean}
 */
function postOrderTraverse(node, callback) {
  var depth = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
  var index = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
  var parent = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : null;
  var path = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : null;
  if (node.children && node.children.length > 0) {
    for (var i = 0, len = node.children.length; i < len; i++) {
      if (postOrderTraverse(node.children[i], callback, depth + 1, i, node, path ? [].concat((0, _toConsumableArray2["default"])(path), [i]) : [i]) === false) {
        break;
      }
    }
  }
  if (callback(node, depth, index, parent, path) === false) {
    return false;
  }
}

/**
 * @param map
 * @returns {Map<any, any>}
 */
function shallowCloneMap(map) {
  var result = new Map();
  var _iterator = _createForOfIteratorHelper(map.entries()),
    _step;
  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var _step$value = (0, _slicedToArray2["default"])(_step.value, 2),
        key = _step$value[0],
        value = _step$value[1];
      result.set(key, value);
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }
  return result;
}
var _default = {
  isEnableLocalStorage: isEnableLocalStorage,
  isEnableSessionStorage: isEnableSessionStorage,
  isEnableCookieAndStorage: isEnableCookieAndStorage,
  formatCapitalize: formatCapitalize,
  value2Timestamp: value2Timestamp,
  value2Moment: value2Moment,
  enumerateValue: enumerateValue,
  tree: tree,
  getValueByValueField: getValueByValueField,
  getTextByDisplayField: getTextByDisplayField,
  isValueEqual: isValueEqual,
  genIndexArray: genIndexArray,
  getDiag: getDiag,
  reorder: reorder,
  preOrderTraverse: preOrderTraverse,
  postOrderTraverse: postOrderTraverse,
  shallowCloneMap: shallowCloneMap
};
exports["default"] = _default;